@@ -734,21 +734,14 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
                 writer.save()
             ################ computing the metrics per epoch (monthly !)
 
-            daily_df['epoch_number'] = daily_df.index.year.astype(str) + '_' + daily_df.index.month.astype(str)
-
             def compute_metrics(df, strat=None):
                 kpi_df = get_kpi(df[[strat]])
                 return kpi_df.to_dict()[strat]
 
             go_comp_kpi = lambda x: compute_metrics(x, strat=me_strat)
 
-            epochkpis_df = daily_df[['epoch_number', me_strat]].groupby(['epoch_number']).apply(go_comp_kpi)
-
-            epochkpis_df = epochkpis_df.sort_index()
-            epochkpis_df = pd.DataFrame.from_records(epochkpis_df.to_dict()).T
-
-            epochkpis_df['year'] = epochkpis_df.index.year
-            epochkpis_df['month'] = epochkpis_df.index.month
+            daily_df['year'] = daily_df.index.year
+            daily_df['month'] = daily_df.index.month
 
             def rename_month(row):
                 if row['month'] == 1:
@@ -776,10 +769,10 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
                 if row['month'] == 12:
                     return 'December'
 
-            epochkpis_df['month'] = epochkpis_df.apply(rename_month, axis=1)
+            daily_df['month'] = daily_df.apply(rename_month, axis=1)
 
+            epochkpis_df = daily_df[['year', 'month', me_strat]].groupby(['year', 'month']).apply(go_comp_kpi)
             epochkpis_df = epochkpis_df.set_index(['year', 'month'])
-            epochkpis_df = epochkpis_df.drop(columns=['date', 'epoch_number'])
 
             if write_file:
                 writer = pd.ExcelWriter(local_root_directory + f'epoch_{me_strat_name}_{title}.xlsx',
